from django.contrib import admin
from django.utils.translation import gettext as _
from .models import *

@admin.register(Category)
class CategoryAdmin(admin.ModelAdmin):
    """
    The admin model for Category
    """

    list_display = ["name", "slug"]

@admin.action(description=_("Regenerate traits"))
def regenerate(modeladmin, request, queryset):
    for obj in queryset:
        obj.regenerate()

@admin.register(BlogPost)
class BlogPostAdmin(admin.ModelAdmin):
    """
    The admin model for BlogPost
    """
    list_display = ["title_en", "subtitle_en", "title_de", "subtitle_de", "date", "category", "slug", "suburl", "public"]
    date_hierarchy = "date"
    ordering = ['title_de', 'title_en']
    actions = [regenerate]
