from django.db import models
from django.utils.translation import gettext as _
from start.models import Searchable

import logging
logger = logging.getLogger(__name__)

class Category(models.Model):
    """
    A category of blog posts

    Name not translated because it would make i18n in urls and Searchables specifically a pain.
    Maybe some day it would be cool if these were Searchable
    """
    name= models.CharField(max_length=50)
    slug = models.SlugField()

    class Meta:
        verbose_name = _("Category")
        verbose_name_plural = _("Categories")

    def __str__(self):
        return f"{{<{self.__class__.__name__}>\"{self.name}\"}}"

class BlogPost(Searchable):
    """
    Should contain a blogpost
    """
    body_en = models.TextField(default="No english translation yet.")
    body_de = models.TextField(default="Bis jetzt keine deutsche Übersetzung.")
    category = models.ForeignKey(Category, on_delete=models.SET_NULL, null=True)
    thumbnail = models.ImageField(blank=True, upload_to="img/thumbnails")
    featured = models.BooleanField(default=False)
    markdown = models.BooleanField(default=False)
    slug = models.SlugField()


    def regenerate(self):
        """
        regenerate a object

        Implements the abstract method of Searchable
        """
        logger.info(f"regenerating {self.__class__.__name__} object: {self}")
        self.suburl = f"/blog/{self.category.name}/{self.slug}"
        self.save()

    class Meta:
        verbose_name = _("blog post")
        verbose_name_plural = _("blog posts")
